Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterEnSyncServiceServer(s grpc.ServiceRegistrar, srv EnSyncServiceServer)
- type AcknowledgeRequest
- func (*AcknowledgeRequest) Descriptor() ([]byte, []int)deprecated
- func (x *AcknowledgeRequest) GetClientId() string
- func (x *AcknowledgeRequest) GetEventIdem() string
- func (x *AcknowledgeRequest) GetEventName() string
- func (x *AcknowledgeRequest) GetPartitionBlock() int64
- func (*AcknowledgeRequest) ProtoMessage()
- func (x *AcknowledgeRequest) ProtoReflect() protoreflect.Message
- func (x *AcknowledgeRequest) Reset()
- func (x *AcknowledgeRequest) String() string
- type AcknowledgeResponse
- func (*AcknowledgeResponse) Descriptor() ([]byte, []int)deprecated
- func (x *AcknowledgeResponse) GetMessage() string
- func (x *AcknowledgeResponse) GetSuccess() bool
- func (*AcknowledgeResponse) ProtoMessage()
- func (x *AcknowledgeResponse) ProtoReflect() protoreflect.Message
- func (x *AcknowledgeResponse) Reset()
- func (x *AcknowledgeResponse) String() string
- type ConnectRequest
- type ConnectResponse
- func (*ConnectResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ConnectResponse) GetClientHash() string
- func (x *ConnectResponse) GetClientId() string
- func (x *ConnectResponse) GetErrorMessage() string
- func (x *ConnectResponse) GetServerConfig() map[string]string
- func (x *ConnectResponse) GetSuccess() bool
- func (*ConnectResponse) ProtoMessage()
- func (x *ConnectResponse) ProtoReflect() protoreflect.Message
- func (x *ConnectResponse) Reset()
- func (x *ConnectResponse) String() string
- type ContinueRequest
- func (*ContinueRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ContinueRequest) GetClientId() string
- func (x *ContinueRequest) GetEventName() string
- func (*ContinueRequest) ProtoMessage()
- func (x *ContinueRequest) ProtoReflect() protoreflect.Message
- func (x *ContinueRequest) Reset()
- func (x *ContinueRequest) String() string
- type ContinueResponse
- func (*ContinueResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ContinueResponse) GetMessage() string
- func (x *ContinueResponse) GetSuccess() bool
- func (*ContinueResponse) ProtoMessage()
- func (x *ContinueResponse) ProtoReflect() protoreflect.Message
- func (x *ContinueResponse) Reset()
- func (x *ContinueResponse) String() string
- type DeferRequest
- func (*DeferRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeferRequest) GetClientId() string
- func (x *DeferRequest) GetDelayMs() int64
- func (x *DeferRequest) GetEventIdem() string
- func (x *DeferRequest) GetEventName() string
- func (x *DeferRequest) GetPriority() int32
- func (x *DeferRequest) GetReason() string
- func (*DeferRequest) ProtoMessage()
- func (x *DeferRequest) ProtoReflect() protoreflect.Message
- func (x *DeferRequest) Reset()
- func (x *DeferRequest) String() string
- type DeferResponse
- func (*DeferResponse) Descriptor() ([]byte, []int)deprecated
- func (x *DeferResponse) GetDeliveryTime() int64
- func (x *DeferResponse) GetMessage() string
- func (x *DeferResponse) GetSuccess() bool
- func (*DeferResponse) ProtoMessage()
- func (x *DeferResponse) ProtoReflect() protoreflect.Message
- func (x *DeferResponse) Reset()
- func (x *DeferResponse) String() string
- type DiscardRequest
- func (*DiscardRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DiscardRequest) GetClientId() string
- func (x *DiscardRequest) GetEventIdem() string
- func (x *DiscardRequest) GetEventName() string
- func (x *DiscardRequest) GetReason() string
- func (*DiscardRequest) ProtoMessage()
- func (x *DiscardRequest) ProtoReflect() protoreflect.Message
- func (x *DiscardRequest) Reset()
- func (x *DiscardRequest) String() string
- type DiscardResponse
- func (*DiscardResponse) Descriptor() ([]byte, []int)deprecated
- func (x *DiscardResponse) GetMessage() string
- func (x *DiscardResponse) GetSuccess() bool
- func (*DiscardResponse) ProtoMessage()
- func (x *DiscardResponse) ProtoReflect() protoreflect.Message
- func (x *DiscardResponse) Reset()
- func (x *DiscardResponse) String() string
- type EnSyncServiceClient
- type EnSyncServiceServer
- type EnSyncService_SubscribeClient
- type EnSyncService_SubscribeServer
- type EventStreamResponse
- func (*EventStreamResponse) Descriptor() ([]byte, []int)deprecated
- func (x *EventStreamResponse) GetEventIdem() string
- func (x *EventStreamResponse) GetEventName() string
- func (x *EventStreamResponse) GetMetadata() string
- func (x *EventStreamResponse) GetPartitionBlock() int64
- func (x *EventStreamResponse) GetPayload() string
- func (x *EventStreamResponse) GetSender() string
- func (*EventStreamResponse) ProtoMessage()
- func (x *EventStreamResponse) ProtoReflect() protoreflect.Message
- func (x *EventStreamResponse) Reset()
- func (x *EventStreamResponse) String() string
- type HeartbeatRequest
- type HeartbeatResponse
- type PauseRequest
- func (*PauseRequest) Descriptor() ([]byte, []int)deprecated
- func (x *PauseRequest) GetClientId() string
- func (x *PauseRequest) GetEventName() string
- func (x *PauseRequest) GetReason() string
- func (*PauseRequest) ProtoMessage()
- func (x *PauseRequest) ProtoReflect() protoreflect.Message
- func (x *PauseRequest) Reset()
- func (x *PauseRequest) String() string
- type PauseResponse
- func (*PauseResponse) Descriptor() ([]byte, []int)deprecated
- func (x *PauseResponse) GetMessage() string
- func (x *PauseResponse) GetSuccess() bool
- func (*PauseResponse) ProtoMessage()
- func (x *PauseResponse) ProtoReflect() protoreflect.Message
- func (x *PauseResponse) Reset()
- func (x *PauseResponse) String() string
- type PublishEventRequest
- func (*PublishEventRequest) Descriptor() ([]byte, []int)deprecated
- func (x *PublishEventRequest) GetClientId() string
- func (x *PublishEventRequest) GetDeliveryTo() string
- func (x *PublishEventRequest) GetEventName() string
- func (x *PublishEventRequest) GetMetadata() string
- func (x *PublishEventRequest) GetPayload() string
- func (x *PublishEventRequest) GetPayloadMetadata() string
- func (*PublishEventRequest) ProtoMessage()
- func (x *PublishEventRequest) ProtoReflect() protoreflect.Message
- func (x *PublishEventRequest) Reset()
- func (x *PublishEventRequest) String() string
- type PublishEventResponse
- func (*PublishEventResponse) Descriptor() ([]byte, []int)deprecated
- func (x *PublishEventResponse) GetErrorMessage() string
- func (x *PublishEventResponse) GetEventIdem() string
- func (x *PublishEventResponse) GetSuccess() bool
- func (*PublishEventResponse) ProtoMessage()
- func (x *PublishEventResponse) ProtoReflect() protoreflect.Message
- func (x *PublishEventResponse) Reset()
- func (x *PublishEventResponse) String() string
- type ReplayRequest
- func (*ReplayRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ReplayRequest) GetClientId() string
- func (x *ReplayRequest) GetEventIdem() string
- func (x *ReplayRequest) GetEventName() string
- func (*ReplayRequest) ProtoMessage()
- func (x *ReplayRequest) ProtoReflect() protoreflect.Message
- func (x *ReplayRequest) Reset()
- func (x *ReplayRequest) String() string
- type ReplayResponse
- func (*ReplayResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ReplayResponse) GetEventData() string
- func (x *ReplayResponse) GetMessage() string
- func (x *ReplayResponse) GetSuccess() bool
- func (*ReplayResponse) ProtoMessage()
- func (x *ReplayResponse) ProtoReflect() protoreflect.Message
- func (x *ReplayResponse) Reset()
- func (x *ReplayResponse) String() string
- type SubscribeRequest
- func (*SubscribeRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SubscribeRequest) GetClientId() string
- func (x *SubscribeRequest) GetEventName() string
- func (*SubscribeRequest) ProtoMessage()
- func (x *SubscribeRequest) ProtoReflect() protoreflect.Message
- func (x *SubscribeRequest) Reset()
- func (x *SubscribeRequest) String() string
- type UnimplementedEnSyncServiceServer
- func (UnimplementedEnSyncServiceServer) AcknowledgeEvent(context.Context, *AcknowledgeRequest) (*AcknowledgeResponse, error)
- func (UnimplementedEnSyncServiceServer) Connect(context.Context, *ConnectRequest) (*ConnectResponse, error)
- func (UnimplementedEnSyncServiceServer) ContinueEvents(context.Context, *ContinueRequest) (*ContinueResponse, error)
- func (UnimplementedEnSyncServiceServer) DeferEvent(context.Context, *DeferRequest) (*DeferResponse, error)
- func (UnimplementedEnSyncServiceServer) DiscardEvent(context.Context, *DiscardRequest) (*DiscardResponse, error)
- func (UnimplementedEnSyncServiceServer) Heartbeat(context.Context, *HeartbeatRequest) (*HeartbeatResponse, error)
- func (UnimplementedEnSyncServiceServer) PauseEvents(context.Context, *PauseRequest) (*PauseResponse, error)
- func (UnimplementedEnSyncServiceServer) PublishEvent(context.Context, *PublishEventRequest) (*PublishEventResponse, error)
- func (UnimplementedEnSyncServiceServer) ReplayEvent(context.Context, *ReplayRequest) (*ReplayResponse, error)
- func (UnimplementedEnSyncServiceServer) Subscribe(*SubscribeRequest, grpc.ServerStreamingServer[EventStreamResponse]) error
- func (UnimplementedEnSyncServiceServer) Unsubscribe(context.Context, *UnsubscribeRequest) (*UnsubscribeResponse, error)
- type UnsafeEnSyncServiceServer
- type UnsubscribeRequest
- func (*UnsubscribeRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UnsubscribeRequest) GetClientId() string
- func (x *UnsubscribeRequest) GetEventName() string
- func (*UnsubscribeRequest) ProtoMessage()
- func (x *UnsubscribeRequest) ProtoReflect() protoreflect.Message
- func (x *UnsubscribeRequest) Reset()
- func (x *UnsubscribeRequest) String() string
- type UnsubscribeResponse
- func (*UnsubscribeResponse) Descriptor() ([]byte, []int)deprecated
- func (x *UnsubscribeResponse) GetMessage() string
- func (x *UnsubscribeResponse) GetSuccess() bool
- func (*UnsubscribeResponse) ProtoMessage()
- func (x *UnsubscribeResponse) ProtoReflect() protoreflect.Message
- func (x *UnsubscribeResponse) Reset()
- func (x *UnsubscribeResponse) String() string
Constants ¶
const ( EnSyncService_Connect_FullMethodName = "/ensync.EnSyncService/Connect" EnSyncService_Heartbeat_FullMethodName = "/ensync.EnSyncService/Heartbeat" EnSyncService_PublishEvent_FullMethodName = "/ensync.EnSyncService/PublishEvent" EnSyncService_Subscribe_FullMethodName = "/ensync.EnSyncService/Subscribe" EnSyncService_Unsubscribe_FullMethodName = "/ensync.EnSyncService/Unsubscribe" EnSyncService_AcknowledgeEvent_FullMethodName = "/ensync.EnSyncService/AcknowledgeEvent" EnSyncService_DeferEvent_FullMethodName = "/ensync.EnSyncService/DeferEvent" EnSyncService_DiscardEvent_FullMethodName = "/ensync.EnSyncService/DiscardEvent" EnSyncService_ReplayEvent_FullMethodName = "/ensync.EnSyncService/ReplayEvent" EnSyncService_PauseEvents_FullMethodName = "/ensync.EnSyncService/PauseEvents" EnSyncService_ContinueEvents_FullMethodName = "/ensync.EnSyncService/ContinueEvents" )
Variables ¶
var EnSyncService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "ensync.EnSyncService", HandlerType: (*EnSyncServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Connect", Handler: _EnSyncService_Connect_Handler, }, { MethodName: "Heartbeat", Handler: _EnSyncService_Heartbeat_Handler, }, { MethodName: "PublishEvent", Handler: _EnSyncService_PublishEvent_Handler, }, { MethodName: "Unsubscribe", Handler: _EnSyncService_Unsubscribe_Handler, }, { MethodName: "AcknowledgeEvent", Handler: _EnSyncService_AcknowledgeEvent_Handler, }, { MethodName: "DeferEvent", Handler: _EnSyncService_DeferEvent_Handler, }, { MethodName: "DiscardEvent", Handler: _EnSyncService_DiscardEvent_Handler, }, { MethodName: "ReplayEvent", Handler: _EnSyncService_ReplayEvent_Handler, }, { MethodName: "PauseEvents", Handler: _EnSyncService_PauseEvents_Handler, }, { MethodName: "ContinueEvents", Handler: _EnSyncService_ContinueEvents_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "Subscribe", Handler: _EnSyncService_Subscribe_Handler, ServerStreams: true, }, }, Metadata: "internal/proto/ensync.proto", }
EnSyncService_ServiceDesc is the grpc.ServiceDesc for EnSyncService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_internal_proto_ensync_proto protoreflect.FileDescriptor
Functions ¶
func RegisterEnSyncServiceServer ¶
func RegisterEnSyncServiceServer(s grpc.ServiceRegistrar, srv EnSyncServiceServer)
Types ¶
type AcknowledgeRequest ¶
type AcknowledgeRequest struct {
ClientId string `protobuf:"bytes,1,opt,name=client_id,json=clientId,proto3" json:"client_id,omitempty"`
EventIdem string `protobuf:"bytes,2,opt,name=event_idem,json=eventIdem,proto3" json:"event_idem,omitempty"`
EventName string `protobuf:"bytes,3,opt,name=event_name,json=eventName,proto3" json:"event_name,omitempty"`
PartitionBlock int64 `protobuf:"varint,4,opt,name=partition_block,json=partitionBlock,proto3" json:"partition_block,omitempty"`
// contains filtered or unexported fields
}
Event Management Messages
func (*AcknowledgeRequest) Descriptor
deprecated
func (*AcknowledgeRequest) Descriptor() ([]byte, []int)
Deprecated: Use AcknowledgeRequest.ProtoReflect.Descriptor instead.
func (*AcknowledgeRequest) GetClientId ¶
func (x *AcknowledgeRequest) GetClientId() string
func (*AcknowledgeRequest) GetEventIdem ¶
func (x *AcknowledgeRequest) GetEventIdem() string
func (*AcknowledgeRequest) GetEventName ¶
func (x *AcknowledgeRequest) GetEventName() string
func (*AcknowledgeRequest) GetPartitionBlock ¶
func (x *AcknowledgeRequest) GetPartitionBlock() int64
func (*AcknowledgeRequest) ProtoMessage ¶
func (*AcknowledgeRequest) ProtoMessage()
func (*AcknowledgeRequest) ProtoReflect ¶
func (x *AcknowledgeRequest) ProtoReflect() protoreflect.Message
func (*AcknowledgeRequest) Reset ¶
func (x *AcknowledgeRequest) Reset()
func (*AcknowledgeRequest) String ¶
func (x *AcknowledgeRequest) String() string
type AcknowledgeResponse ¶
type AcknowledgeResponse struct {
Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
// contains filtered or unexported fields
}
func (*AcknowledgeResponse) Descriptor
deprecated
func (*AcknowledgeResponse) Descriptor() ([]byte, []int)
Deprecated: Use AcknowledgeResponse.ProtoReflect.Descriptor instead.
func (*AcknowledgeResponse) GetMessage ¶
func (x *AcknowledgeResponse) GetMessage() string
func (*AcknowledgeResponse) GetSuccess ¶
func (x *AcknowledgeResponse) GetSuccess() bool
func (*AcknowledgeResponse) ProtoMessage ¶
func (*AcknowledgeResponse) ProtoMessage()
func (*AcknowledgeResponse) ProtoReflect ¶
func (x *AcknowledgeResponse) ProtoReflect() protoreflect.Message
func (*AcknowledgeResponse) Reset ¶
func (x *AcknowledgeResponse) Reset()
func (*AcknowledgeResponse) String ¶
func (x *AcknowledgeResponse) String() string
type ConnectRequest ¶
type ConnectRequest struct {
AccessKey string `protobuf:"bytes,1,opt,name=access_key,json=accessKey,proto3" json:"access_key,omitempty"`
// contains filtered or unexported fields
}
Connection Messages
func (*ConnectRequest) Descriptor
deprecated
func (*ConnectRequest) Descriptor() ([]byte, []int)
Deprecated: Use ConnectRequest.ProtoReflect.Descriptor instead.
func (*ConnectRequest) GetAccessKey ¶
func (x *ConnectRequest) GetAccessKey() string
func (*ConnectRequest) ProtoMessage ¶
func (*ConnectRequest) ProtoMessage()
func (*ConnectRequest) ProtoReflect ¶
func (x *ConnectRequest) ProtoReflect() protoreflect.Message
func (*ConnectRequest) Reset ¶
func (x *ConnectRequest) Reset()
func (*ConnectRequest) String ¶
func (x *ConnectRequest) String() string
type ConnectResponse ¶
type ConnectResponse struct {
Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
ClientId string `protobuf:"bytes,2,opt,name=client_id,json=clientId,proto3" json:"client_id,omitempty"`
ClientHash string `protobuf:"bytes,3,opt,name=client_hash,json=clientHash,proto3" json:"client_hash,omitempty"`
ServerConfig map[string]string `` /* 185-byte string literal not displayed */
ErrorMessage string `protobuf:"bytes,5,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
// contains filtered or unexported fields
}
func (*ConnectResponse) Descriptor
deprecated
func (*ConnectResponse) Descriptor() ([]byte, []int)
Deprecated: Use ConnectResponse.ProtoReflect.Descriptor instead.
func (*ConnectResponse) GetClientHash ¶
func (x *ConnectResponse) GetClientHash() string
func (*ConnectResponse) GetClientId ¶
func (x *ConnectResponse) GetClientId() string
func (*ConnectResponse) GetErrorMessage ¶
func (x *ConnectResponse) GetErrorMessage() string
func (*ConnectResponse) GetServerConfig ¶
func (x *ConnectResponse) GetServerConfig() map[string]string
func (*ConnectResponse) GetSuccess ¶
func (x *ConnectResponse) GetSuccess() bool
func (*ConnectResponse) ProtoMessage ¶
func (*ConnectResponse) ProtoMessage()
func (*ConnectResponse) ProtoReflect ¶
func (x *ConnectResponse) ProtoReflect() protoreflect.Message
func (*ConnectResponse) Reset ¶
func (x *ConnectResponse) Reset()
func (*ConnectResponse) String ¶
func (x *ConnectResponse) String() string
type ContinueRequest ¶
type ContinueRequest struct {
ClientId string `protobuf:"bytes,1,opt,name=client_id,json=clientId,proto3" json:"client_id,omitempty"`
EventName string `protobuf:"bytes,2,opt,name=event_name,json=eventName,proto3" json:"event_name,omitempty"`
// contains filtered or unexported fields
}
func (*ContinueRequest) Descriptor
deprecated
func (*ContinueRequest) Descriptor() ([]byte, []int)
Deprecated: Use ContinueRequest.ProtoReflect.Descriptor instead.
func (*ContinueRequest) GetClientId ¶
func (x *ContinueRequest) GetClientId() string
func (*ContinueRequest) GetEventName ¶
func (x *ContinueRequest) GetEventName() string
func (*ContinueRequest) ProtoMessage ¶
func (*ContinueRequest) ProtoMessage()
func (*ContinueRequest) ProtoReflect ¶
func (x *ContinueRequest) ProtoReflect() protoreflect.Message
func (*ContinueRequest) Reset ¶
func (x *ContinueRequest) Reset()
func (*ContinueRequest) String ¶
func (x *ContinueRequest) String() string
type ContinueResponse ¶
type ContinueResponse struct {
Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
// contains filtered or unexported fields
}
func (*ContinueResponse) Descriptor
deprecated
func (*ContinueResponse) Descriptor() ([]byte, []int)
Deprecated: Use ContinueResponse.ProtoReflect.Descriptor instead.
func (*ContinueResponse) GetMessage ¶
func (x *ContinueResponse) GetMessage() string
func (*ContinueResponse) GetSuccess ¶
func (x *ContinueResponse) GetSuccess() bool
func (*ContinueResponse) ProtoMessage ¶
func (*ContinueResponse) ProtoMessage()
func (*ContinueResponse) ProtoReflect ¶
func (x *ContinueResponse) ProtoReflect() protoreflect.Message
func (*ContinueResponse) Reset ¶
func (x *ContinueResponse) Reset()
func (*ContinueResponse) String ¶
func (x *ContinueResponse) String() string
type DeferRequest ¶
type DeferRequest struct {
ClientId string `protobuf:"bytes,1,opt,name=client_id,json=clientId,proto3" json:"client_id,omitempty"`
EventIdem string `protobuf:"bytes,2,opt,name=event_idem,json=eventIdem,proto3" json:"event_idem,omitempty"`
EventName string `protobuf:"bytes,3,opt,name=event_name,json=eventName,proto3" json:"event_name,omitempty"`
DelayMs int64 `protobuf:"varint,4,opt,name=delay_ms,json=delayMs,proto3" json:"delay_ms,omitempty"`
Priority int32 `protobuf:"varint,5,opt,name=priority,proto3" json:"priority,omitempty"`
Reason string `protobuf:"bytes,6,opt,name=reason,proto3" json:"reason,omitempty"`
// contains filtered or unexported fields
}
func (*DeferRequest) Descriptor
deprecated
func (*DeferRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeferRequest.ProtoReflect.Descriptor instead.
func (*DeferRequest) GetClientId ¶
func (x *DeferRequest) GetClientId() string
func (*DeferRequest) GetDelayMs ¶
func (x *DeferRequest) GetDelayMs() int64
func (*DeferRequest) GetEventIdem ¶
func (x *DeferRequest) GetEventIdem() string
func (*DeferRequest) GetEventName ¶
func (x *DeferRequest) GetEventName() string
func (*DeferRequest) GetPriority ¶
func (x *DeferRequest) GetPriority() int32
func (*DeferRequest) GetReason ¶
func (x *DeferRequest) GetReason() string
func (*DeferRequest) ProtoMessage ¶
func (*DeferRequest) ProtoMessage()
func (*DeferRequest) ProtoReflect ¶
func (x *DeferRequest) ProtoReflect() protoreflect.Message
func (*DeferRequest) Reset ¶
func (x *DeferRequest) Reset()
func (*DeferRequest) String ¶
func (x *DeferRequest) String() string
type DeferResponse ¶
type DeferResponse struct {
Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
DeliveryTime int64 `protobuf:"varint,3,opt,name=delivery_time,json=deliveryTime,proto3" json:"delivery_time,omitempty"`
// contains filtered or unexported fields
}
func (*DeferResponse) Descriptor
deprecated
func (*DeferResponse) Descriptor() ([]byte, []int)
Deprecated: Use DeferResponse.ProtoReflect.Descriptor instead.
func (*DeferResponse) GetDeliveryTime ¶
func (x *DeferResponse) GetDeliveryTime() int64
func (*DeferResponse) GetMessage ¶
func (x *DeferResponse) GetMessage() string
func (*DeferResponse) GetSuccess ¶
func (x *DeferResponse) GetSuccess() bool
func (*DeferResponse) ProtoMessage ¶
func (*DeferResponse) ProtoMessage()
func (*DeferResponse) ProtoReflect ¶
func (x *DeferResponse) ProtoReflect() protoreflect.Message
func (*DeferResponse) Reset ¶
func (x *DeferResponse) Reset()
func (*DeferResponse) String ¶
func (x *DeferResponse) String() string
type DiscardRequest ¶
type DiscardRequest struct {
ClientId string `protobuf:"bytes,1,opt,name=client_id,json=clientId,proto3" json:"client_id,omitempty"`
EventIdem string `protobuf:"bytes,2,opt,name=event_idem,json=eventIdem,proto3" json:"event_idem,omitempty"`
EventName string `protobuf:"bytes,3,opt,name=event_name,json=eventName,proto3" json:"event_name,omitempty"`
Reason string `protobuf:"bytes,4,opt,name=reason,proto3" json:"reason,omitempty"`
// contains filtered or unexported fields
}
func (*DiscardRequest) Descriptor
deprecated
func (*DiscardRequest) Descriptor() ([]byte, []int)
Deprecated: Use DiscardRequest.ProtoReflect.Descriptor instead.
func (*DiscardRequest) GetClientId ¶
func (x *DiscardRequest) GetClientId() string
func (*DiscardRequest) GetEventIdem ¶
func (x *DiscardRequest) GetEventIdem() string
func (*DiscardRequest) GetEventName ¶
func (x *DiscardRequest) GetEventName() string
func (*DiscardRequest) GetReason ¶
func (x *DiscardRequest) GetReason() string
func (*DiscardRequest) ProtoMessage ¶
func (*DiscardRequest) ProtoMessage()
func (*DiscardRequest) ProtoReflect ¶
func (x *DiscardRequest) ProtoReflect() protoreflect.Message
func (*DiscardRequest) Reset ¶
func (x *DiscardRequest) Reset()
func (*DiscardRequest) String ¶
func (x *DiscardRequest) String() string
type DiscardResponse ¶
type DiscardResponse struct {
Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
// contains filtered or unexported fields
}
func (*DiscardResponse) Descriptor
deprecated
func (*DiscardResponse) Descriptor() ([]byte, []int)
Deprecated: Use DiscardResponse.ProtoReflect.Descriptor instead.
func (*DiscardResponse) GetMessage ¶
func (x *DiscardResponse) GetMessage() string
func (*DiscardResponse) GetSuccess ¶
func (x *DiscardResponse) GetSuccess() bool
func (*DiscardResponse) ProtoMessage ¶
func (*DiscardResponse) ProtoMessage()
func (*DiscardResponse) ProtoReflect ¶
func (x *DiscardResponse) ProtoReflect() protoreflect.Message
func (*DiscardResponse) Reset ¶
func (x *DiscardResponse) Reset()
func (*DiscardResponse) String ¶
func (x *DiscardResponse) String() string
type EnSyncServiceClient ¶
type EnSyncServiceClient interface {
// Connection & Authentication
Connect(ctx context.Context, in *ConnectRequest, opts ...grpc.CallOption) (*ConnectResponse, error)
Heartbeat(ctx context.Context, in *HeartbeatRequest, opts ...grpc.CallOption) (*HeartbeatResponse, error)
// Event Publishing
PublishEvent(ctx context.Context, in *PublishEventRequest, opts ...grpc.CallOption) (*PublishEventResponse, error)
// Event Subscription - Returns a stream of events
Subscribe(ctx context.Context, in *SubscribeRequest, opts ...grpc.CallOption) (grpc.ServerStreamingClient[EventStreamResponse], error)
Unsubscribe(ctx context.Context, in *UnsubscribeRequest, opts ...grpc.CallOption) (*UnsubscribeResponse, error)
// Event Management
AcknowledgeEvent(ctx context.Context, in *AcknowledgeRequest, opts ...grpc.CallOption) (*AcknowledgeResponse, error)
DeferEvent(ctx context.Context, in *DeferRequest, opts ...grpc.CallOption) (*DeferResponse, error)
DiscardEvent(ctx context.Context, in *DiscardRequest, opts ...grpc.CallOption) (*DiscardResponse, error)
ReplayEvent(ctx context.Context, in *ReplayRequest, opts ...grpc.CallOption) (*ReplayResponse, error)
// Flow Control
PauseEvents(ctx context.Context, in *PauseRequest, opts ...grpc.CallOption) (*PauseResponse, error)
ContinueEvents(ctx context.Context, in *ContinueRequest, opts ...grpc.CallOption) (*ContinueResponse, error)
}
EnSyncServiceClient is the client API for EnSyncService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
Main EnSync service for client communication
func NewEnSyncServiceClient ¶
func NewEnSyncServiceClient(cc grpc.ClientConnInterface) EnSyncServiceClient
type EnSyncServiceServer ¶
type EnSyncServiceServer interface {
// Connection & Authentication
Connect(context.Context, *ConnectRequest) (*ConnectResponse, error)
Heartbeat(context.Context, *HeartbeatRequest) (*HeartbeatResponse, error)
// Event Publishing
PublishEvent(context.Context, *PublishEventRequest) (*PublishEventResponse, error)
// Event Subscription - Returns a stream of events
Subscribe(*SubscribeRequest, grpc.ServerStreamingServer[EventStreamResponse]) error
Unsubscribe(context.Context, *UnsubscribeRequest) (*UnsubscribeResponse, error)
// Event Management
AcknowledgeEvent(context.Context, *AcknowledgeRequest) (*AcknowledgeResponse, error)
DeferEvent(context.Context, *DeferRequest) (*DeferResponse, error)
DiscardEvent(context.Context, *DiscardRequest) (*DiscardResponse, error)
ReplayEvent(context.Context, *ReplayRequest) (*ReplayResponse, error)
// Flow Control
PauseEvents(context.Context, *PauseRequest) (*PauseResponse, error)
ContinueEvents(context.Context, *ContinueRequest) (*ContinueResponse, error)
// contains filtered or unexported methods
}
EnSyncServiceServer is the server API for EnSyncService service. All implementations must embed UnimplementedEnSyncServiceServer for forward compatibility.
Main EnSync service for client communication
type EnSyncService_SubscribeClient ¶
type EnSyncService_SubscribeClient = grpc.ServerStreamingClient[EventStreamResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type EnSyncService_SubscribeServer ¶
type EnSyncService_SubscribeServer = grpc.ServerStreamingServer[EventStreamResponse]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type EventStreamResponse ¶
type EventStreamResponse struct {
EventIdem string `protobuf:"bytes,1,opt,name=event_idem,json=eventIdem,proto3" json:"event_idem,omitempty"`
EventName string `protobuf:"bytes,2,opt,name=event_name,json=eventName,proto3" json:"event_name,omitempty"`
Payload string `protobuf:"bytes,3,opt,name=payload,proto3" json:"payload,omitempty"`
PartitionBlock int64 `protobuf:"varint,4,opt,name=partition_block,json=partitionBlock,proto3" json:"partition_block,omitempty"`
Metadata string `protobuf:"bytes,5,opt,name=metadata,proto3" json:"metadata,omitempty"`
Sender string `protobuf:"bytes,6,opt,name=sender,proto3" json:"sender,omitempty"`
// contains filtered or unexported fields
}
func (*EventStreamResponse) Descriptor
deprecated
func (*EventStreamResponse) Descriptor() ([]byte, []int)
Deprecated: Use EventStreamResponse.ProtoReflect.Descriptor instead.
func (*EventStreamResponse) GetEventIdem ¶
func (x *EventStreamResponse) GetEventIdem() string
func (*EventStreamResponse) GetEventName ¶
func (x *EventStreamResponse) GetEventName() string
func (*EventStreamResponse) GetMetadata ¶
func (x *EventStreamResponse) GetMetadata() string
func (*EventStreamResponse) GetPartitionBlock ¶
func (x *EventStreamResponse) GetPartitionBlock() int64
func (*EventStreamResponse) GetPayload ¶
func (x *EventStreamResponse) GetPayload() string
func (*EventStreamResponse) GetSender ¶
func (x *EventStreamResponse) GetSender() string
func (*EventStreamResponse) ProtoMessage ¶
func (*EventStreamResponse) ProtoMessage()
func (*EventStreamResponse) ProtoReflect ¶
func (x *EventStreamResponse) ProtoReflect() protoreflect.Message
func (*EventStreamResponse) Reset ¶
func (x *EventStreamResponse) Reset()
func (*EventStreamResponse) String ¶
func (x *EventStreamResponse) String() string
type HeartbeatRequest ¶
type HeartbeatRequest struct {
ClientId string `protobuf:"bytes,1,opt,name=client_id,json=clientId,proto3" json:"client_id,omitempty"`
// contains filtered or unexported fields
}
func (*HeartbeatRequest) Descriptor
deprecated
func (*HeartbeatRequest) Descriptor() ([]byte, []int)
Deprecated: Use HeartbeatRequest.ProtoReflect.Descriptor instead.
func (*HeartbeatRequest) GetClientId ¶
func (x *HeartbeatRequest) GetClientId() string
func (*HeartbeatRequest) ProtoMessage ¶
func (*HeartbeatRequest) ProtoMessage()
func (*HeartbeatRequest) ProtoReflect ¶
func (x *HeartbeatRequest) ProtoReflect() protoreflect.Message
func (*HeartbeatRequest) Reset ¶
func (x *HeartbeatRequest) Reset()
func (*HeartbeatRequest) String ¶
func (x *HeartbeatRequest) String() string
type HeartbeatResponse ¶
type HeartbeatResponse struct {
Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
// contains filtered or unexported fields
}
func (*HeartbeatResponse) Descriptor
deprecated
func (*HeartbeatResponse) Descriptor() ([]byte, []int)
Deprecated: Use HeartbeatResponse.ProtoReflect.Descriptor instead.
func (*HeartbeatResponse) GetSuccess ¶
func (x *HeartbeatResponse) GetSuccess() bool
func (*HeartbeatResponse) ProtoMessage ¶
func (*HeartbeatResponse) ProtoMessage()
func (*HeartbeatResponse) ProtoReflect ¶
func (x *HeartbeatResponse) ProtoReflect() protoreflect.Message
func (*HeartbeatResponse) Reset ¶
func (x *HeartbeatResponse) Reset()
func (*HeartbeatResponse) String ¶
func (x *HeartbeatResponse) String() string
type PauseRequest ¶
type PauseRequest struct {
ClientId string `protobuf:"bytes,1,opt,name=client_id,json=clientId,proto3" json:"client_id,omitempty"`
EventName string `protobuf:"bytes,2,opt,name=event_name,json=eventName,proto3" json:"event_name,omitempty"`
Reason string `protobuf:"bytes,3,opt,name=reason,proto3" json:"reason,omitempty"`
// contains filtered or unexported fields
}
Flow Control Messages
func (*PauseRequest) Descriptor
deprecated
func (*PauseRequest) Descriptor() ([]byte, []int)
Deprecated: Use PauseRequest.ProtoReflect.Descriptor instead.
func (*PauseRequest) GetClientId ¶
func (x *PauseRequest) GetClientId() string
func (*PauseRequest) GetEventName ¶
func (x *PauseRequest) GetEventName() string
func (*PauseRequest) GetReason ¶
func (x *PauseRequest) GetReason() string
func (*PauseRequest) ProtoMessage ¶
func (*PauseRequest) ProtoMessage()
func (*PauseRequest) ProtoReflect ¶
func (x *PauseRequest) ProtoReflect() protoreflect.Message
func (*PauseRequest) Reset ¶
func (x *PauseRequest) Reset()
func (*PauseRequest) String ¶
func (x *PauseRequest) String() string
type PauseResponse ¶
type PauseResponse struct {
Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
// contains filtered or unexported fields
}
func (*PauseResponse) Descriptor
deprecated
func (*PauseResponse) Descriptor() ([]byte, []int)
Deprecated: Use PauseResponse.ProtoReflect.Descriptor instead.
func (*PauseResponse) GetMessage ¶
func (x *PauseResponse) GetMessage() string
func (*PauseResponse) GetSuccess ¶
func (x *PauseResponse) GetSuccess() bool
func (*PauseResponse) ProtoMessage ¶
func (*PauseResponse) ProtoMessage()
func (*PauseResponse) ProtoReflect ¶
func (x *PauseResponse) ProtoReflect() protoreflect.Message
func (*PauseResponse) Reset ¶
func (x *PauseResponse) Reset()
func (*PauseResponse) String ¶
func (x *PauseResponse) String() string
type PublishEventRequest ¶
type PublishEventRequest struct {
ClientId string `protobuf:"bytes,1,opt,name=client_id,json=clientId,proto3" json:"client_id,omitempty"`
EventName string `protobuf:"bytes,2,opt,name=event_name,json=eventName,proto3" json:"event_name,omitempty"`
Payload string `protobuf:"bytes,3,opt,name=payload,proto3" json:"payload,omitempty"`
DeliveryTo string `protobuf:"bytes,4,opt,name=delivery_to,json=deliveryTo,proto3" json:"delivery_to,omitempty"`
Metadata string `protobuf:"bytes,5,opt,name=metadata,proto3" json:"metadata,omitempty"`
PayloadMetadata *string `protobuf:"bytes,6,opt,name=payload_metadata,json=payloadMetadata,proto3,oneof" json:"payload_metadata,omitempty"`
// contains filtered or unexported fields
}
Event Publishing Messages
func (*PublishEventRequest) Descriptor
deprecated
func (*PublishEventRequest) Descriptor() ([]byte, []int)
Deprecated: Use PublishEventRequest.ProtoReflect.Descriptor instead.
func (*PublishEventRequest) GetClientId ¶
func (x *PublishEventRequest) GetClientId() string
func (*PublishEventRequest) GetDeliveryTo ¶
func (x *PublishEventRequest) GetDeliveryTo() string
func (*PublishEventRequest) GetEventName ¶
func (x *PublishEventRequest) GetEventName() string
func (*PublishEventRequest) GetMetadata ¶
func (x *PublishEventRequest) GetMetadata() string
func (*PublishEventRequest) GetPayload ¶
func (x *PublishEventRequest) GetPayload() string
func (*PublishEventRequest) GetPayloadMetadata ¶
func (x *PublishEventRequest) GetPayloadMetadata() string
func (*PublishEventRequest) ProtoMessage ¶
func (*PublishEventRequest) ProtoMessage()
func (*PublishEventRequest) ProtoReflect ¶
func (x *PublishEventRequest) ProtoReflect() protoreflect.Message
func (*PublishEventRequest) Reset ¶
func (x *PublishEventRequest) Reset()
func (*PublishEventRequest) String ¶
func (x *PublishEventRequest) String() string
type PublishEventResponse ¶
type PublishEventResponse struct {
Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
EventIdem string `protobuf:"bytes,2,opt,name=event_idem,json=eventIdem,proto3" json:"event_idem,omitempty"`
ErrorMessage string `protobuf:"bytes,3,opt,name=error_message,json=errorMessage,proto3" json:"error_message,omitempty"`
// contains filtered or unexported fields
}
func (*PublishEventResponse) Descriptor
deprecated
func (*PublishEventResponse) Descriptor() ([]byte, []int)
Deprecated: Use PublishEventResponse.ProtoReflect.Descriptor instead.
func (*PublishEventResponse) GetErrorMessage ¶
func (x *PublishEventResponse) GetErrorMessage() string
func (*PublishEventResponse) GetEventIdem ¶
func (x *PublishEventResponse) GetEventIdem() string
func (*PublishEventResponse) GetSuccess ¶
func (x *PublishEventResponse) GetSuccess() bool
func (*PublishEventResponse) ProtoMessage ¶
func (*PublishEventResponse) ProtoMessage()
func (*PublishEventResponse) ProtoReflect ¶
func (x *PublishEventResponse) ProtoReflect() protoreflect.Message
func (*PublishEventResponse) Reset ¶
func (x *PublishEventResponse) Reset()
func (*PublishEventResponse) String ¶
func (x *PublishEventResponse) String() string
type ReplayRequest ¶
type ReplayRequest struct {
ClientId string `protobuf:"bytes,1,opt,name=client_id,json=clientId,proto3" json:"client_id,omitempty"`
EventIdem string `protobuf:"bytes,2,opt,name=event_idem,json=eventIdem,proto3" json:"event_idem,omitempty"`
EventName string `protobuf:"bytes,3,opt,name=event_name,json=eventName,proto3" json:"event_name,omitempty"`
// contains filtered or unexported fields
}
func (*ReplayRequest) Descriptor
deprecated
func (*ReplayRequest) Descriptor() ([]byte, []int)
Deprecated: Use ReplayRequest.ProtoReflect.Descriptor instead.
func (*ReplayRequest) GetClientId ¶
func (x *ReplayRequest) GetClientId() string
func (*ReplayRequest) GetEventIdem ¶
func (x *ReplayRequest) GetEventIdem() string
func (*ReplayRequest) GetEventName ¶
func (x *ReplayRequest) GetEventName() string
func (*ReplayRequest) ProtoMessage ¶
func (*ReplayRequest) ProtoMessage()
func (*ReplayRequest) ProtoReflect ¶
func (x *ReplayRequest) ProtoReflect() protoreflect.Message
func (*ReplayRequest) Reset ¶
func (x *ReplayRequest) Reset()
func (*ReplayRequest) String ¶
func (x *ReplayRequest) String() string
type ReplayResponse ¶
type ReplayResponse struct {
Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
EventData string `protobuf:"bytes,3,opt,name=event_data,json=eventData,proto3" json:"event_data,omitempty"`
// contains filtered or unexported fields
}
func (*ReplayResponse) Descriptor
deprecated
func (*ReplayResponse) Descriptor() ([]byte, []int)
Deprecated: Use ReplayResponse.ProtoReflect.Descriptor instead.
func (*ReplayResponse) GetEventData ¶
func (x *ReplayResponse) GetEventData() string
func (*ReplayResponse) GetMessage ¶
func (x *ReplayResponse) GetMessage() string
func (*ReplayResponse) GetSuccess ¶
func (x *ReplayResponse) GetSuccess() bool
func (*ReplayResponse) ProtoMessage ¶
func (*ReplayResponse) ProtoMessage()
func (*ReplayResponse) ProtoReflect ¶
func (x *ReplayResponse) ProtoReflect() protoreflect.Message
func (*ReplayResponse) Reset ¶
func (x *ReplayResponse) Reset()
func (*ReplayResponse) String ¶
func (x *ReplayResponse) String() string
type SubscribeRequest ¶
type SubscribeRequest struct {
ClientId string `protobuf:"bytes,1,opt,name=client_id,json=clientId,proto3" json:"client_id,omitempty"`
EventName string `protobuf:"bytes,2,opt,name=event_name,json=eventName,proto3" json:"event_name,omitempty"`
// contains filtered or unexported fields
}
Event Subscription Messages
func (*SubscribeRequest) Descriptor
deprecated
func (*SubscribeRequest) Descriptor() ([]byte, []int)
Deprecated: Use SubscribeRequest.ProtoReflect.Descriptor instead.
func (*SubscribeRequest) GetClientId ¶
func (x *SubscribeRequest) GetClientId() string
func (*SubscribeRequest) GetEventName ¶
func (x *SubscribeRequest) GetEventName() string
func (*SubscribeRequest) ProtoMessage ¶
func (*SubscribeRequest) ProtoMessage()
func (*SubscribeRequest) ProtoReflect ¶
func (x *SubscribeRequest) ProtoReflect() protoreflect.Message
func (*SubscribeRequest) Reset ¶
func (x *SubscribeRequest) Reset()
func (*SubscribeRequest) String ¶
func (x *SubscribeRequest) String() string
type UnimplementedEnSyncServiceServer ¶
type UnimplementedEnSyncServiceServer struct{}
UnimplementedEnSyncServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedEnSyncServiceServer) AcknowledgeEvent ¶
func (UnimplementedEnSyncServiceServer) AcknowledgeEvent(context.Context, *AcknowledgeRequest) (*AcknowledgeResponse, error)
func (UnimplementedEnSyncServiceServer) Connect ¶
func (UnimplementedEnSyncServiceServer) Connect(context.Context, *ConnectRequest) (*ConnectResponse, error)
func (UnimplementedEnSyncServiceServer) ContinueEvents ¶
func (UnimplementedEnSyncServiceServer) ContinueEvents(context.Context, *ContinueRequest) (*ContinueResponse, error)
func (UnimplementedEnSyncServiceServer) DeferEvent ¶
func (UnimplementedEnSyncServiceServer) DeferEvent(context.Context, *DeferRequest) (*DeferResponse, error)
func (UnimplementedEnSyncServiceServer) DiscardEvent ¶
func (UnimplementedEnSyncServiceServer) DiscardEvent(context.Context, *DiscardRequest) (*DiscardResponse, error)
func (UnimplementedEnSyncServiceServer) Heartbeat ¶
func (UnimplementedEnSyncServiceServer) Heartbeat(context.Context, *HeartbeatRequest) (*HeartbeatResponse, error)
func (UnimplementedEnSyncServiceServer) PauseEvents ¶
func (UnimplementedEnSyncServiceServer) PauseEvents(context.Context, *PauseRequest) (*PauseResponse, error)
func (UnimplementedEnSyncServiceServer) PublishEvent ¶
func (UnimplementedEnSyncServiceServer) PublishEvent(context.Context, *PublishEventRequest) (*PublishEventResponse, error)
func (UnimplementedEnSyncServiceServer) ReplayEvent ¶
func (UnimplementedEnSyncServiceServer) ReplayEvent(context.Context, *ReplayRequest) (*ReplayResponse, error)
func (UnimplementedEnSyncServiceServer) Subscribe ¶
func (UnimplementedEnSyncServiceServer) Subscribe(*SubscribeRequest, grpc.ServerStreamingServer[EventStreamResponse]) error
func (UnimplementedEnSyncServiceServer) Unsubscribe ¶
func (UnimplementedEnSyncServiceServer) Unsubscribe(context.Context, *UnsubscribeRequest) (*UnsubscribeResponse, error)
type UnsafeEnSyncServiceServer ¶
type UnsafeEnSyncServiceServer interface {
// contains filtered or unexported methods
}
UnsafeEnSyncServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to EnSyncServiceServer will result in compilation errors.
type UnsubscribeRequest ¶
type UnsubscribeRequest struct {
ClientId string `protobuf:"bytes,1,opt,name=client_id,json=clientId,proto3" json:"client_id,omitempty"`
EventName string `protobuf:"bytes,2,opt,name=event_name,json=eventName,proto3" json:"event_name,omitempty"`
// contains filtered or unexported fields
}
func (*UnsubscribeRequest) Descriptor
deprecated
func (*UnsubscribeRequest) Descriptor() ([]byte, []int)
Deprecated: Use UnsubscribeRequest.ProtoReflect.Descriptor instead.
func (*UnsubscribeRequest) GetClientId ¶
func (x *UnsubscribeRequest) GetClientId() string
func (*UnsubscribeRequest) GetEventName ¶
func (x *UnsubscribeRequest) GetEventName() string
func (*UnsubscribeRequest) ProtoMessage ¶
func (*UnsubscribeRequest) ProtoMessage()
func (*UnsubscribeRequest) ProtoReflect ¶
func (x *UnsubscribeRequest) ProtoReflect() protoreflect.Message
func (*UnsubscribeRequest) Reset ¶
func (x *UnsubscribeRequest) Reset()
func (*UnsubscribeRequest) String ¶
func (x *UnsubscribeRequest) String() string
type UnsubscribeResponse ¶
type UnsubscribeResponse struct {
Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
// contains filtered or unexported fields
}
func (*UnsubscribeResponse) Descriptor
deprecated
func (*UnsubscribeResponse) Descriptor() ([]byte, []int)
Deprecated: Use UnsubscribeResponse.ProtoReflect.Descriptor instead.
func (*UnsubscribeResponse) GetMessage ¶
func (x *UnsubscribeResponse) GetMessage() string
func (*UnsubscribeResponse) GetSuccess ¶
func (x *UnsubscribeResponse) GetSuccess() bool
func (*UnsubscribeResponse) ProtoMessage ¶
func (*UnsubscribeResponse) ProtoMessage()
func (*UnsubscribeResponse) ProtoReflect ¶
func (x *UnsubscribeResponse) ProtoReflect() protoreflect.Message
func (*UnsubscribeResponse) Reset ¶
func (x *UnsubscribeResponse) Reset()
func (*UnsubscribeResponse) String ¶
func (x *UnsubscribeResponse) String() string